@@ -89,7 +89,8 @@ setMethod("vcov",
   }
 )
 
-setMethod("mean", signature(x = "IdtSNDE"), function(x,...) { coef(x)$mu } )
+#setMethod("mean", signature(x = "IdtSNDE"), function(x,...) { coef(x)$mu } )
+setMethod("mean", signature(x = "IdtSNDE"), function(x) { coef(x)$mu } )
 setMethod("var", signature(x ="IdtSNDE"), function(x) { coef(x)$Sigma } )
 
 setMethod("cor",
@@ -142,7 +143,8 @@ setMethod("vcov",
   }
 )
 
-setMethod("mean", signature(x = "IdtNandSNDE"), function(x,...) { coef(x)$mu } )
+#setMethod("mean", signature(x = "IdtNandSNDE"), function(x,...) { coef(x)$mu } )
+setMethod("mean", signature(x = "IdtNandSNDE"), function(x) { coef(x)$mu } )
 setMethod("var", signature(x ="IdtNandSNDE"), function(x) { coef(x)$Sigma } )
 
 setMethod("cor",
